@@ -1,11 +1,9 @@
 from . import twilio
-from . import signal
 from . import ahoy
 from . import sendgrid
 
 __all__ = [
     'twilio'
-    'signal'
     'ahoy'
     'sendgrid'
 ]
